#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-ACRI3KRvGQG6xbSi7OpCPE
key:                  dhall-1.42.3-ACRI3KRvGQG6xbSi7OpCPE
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  85e623cc4c9f88ae5e43b42066600ade
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-ACRI3KRvGQG6xbSi7OpCPE
depends:
    Diff-0.5-KEZ9YIzWdyM3F5SFakDIw6
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    aeson-pretty-0.8.10-2ahKkUFGqI8GYiCWzaMQv
    ansi-terminal-1.1-5nZVpYMolxlDp5iPgkZNkW
    atomic-write-0.2.1.1-EcuAhjA7adk9N5jrGik6qa base-4.18.2.1
    base16-bytestring-1.0.2.0-B6baxbSLEYRHmpje8gg5IH
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8beqaZQCG6YFLwD8uR7pTp
    cborg-0.2.10.0-7KEKTCxQLSi835OgAqH3Iy
    cborg-json-0.2.6.0-4Klu1OJo9hZKvWFwzjats6 containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-3GNi95NeZM5CPq9IBPiIsg
    data-fix-0.3.4-7dlHudea334GcJzl7iF8h5 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-4oon1pfjcei5YxwlRFwIb0 exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-FkUJx0ykWveG0YP2KISqmf
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy haskeline-0.8.2.1
    http-client-0.7.19-5FSjI7MK9gs3MzC5wdocYk
    http-client-tls-0.3.6.4-9b928T241RZ4DZFzXPqqQg
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-IhFYCfUpu092G9CaEkXpKA
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-IEaPsqFzCYyC5PgjDXgLBm
    pretty-simple-4.1.4.0-LtzWhaWev3JHDovQEkyBvB
    prettyprinter-1.7.1-3tqZuvkzaQgKArc0IOnBsn
    prettyprinter-ansi-terminal-1.1.4-4JTxmby746A8nB3dZScSYR
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-25vWQKW70jDDFFn5H243Ra
    serialise-0.2.6.1-KGnyFoKw4PY5QvSaJtspjA template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-2fKtKMlQtRjCu7rWLuRBCq
    text-short-0.1.6.1-oo923UdzYsCTZa3wWoX5D
    th-lift-instances-0.1.20-AXUxglL4M8CDRPIbfYe5LR time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-LoSzSzurNX35X2SSxikovd
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

